littlemcmc.QuadPotentialDiagAdapt
=================================

.. currentmodule:: littlemcmc

.. autoclass:: QuadPotentialDiagAdapt

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QuadPotentialDiagAdapt.__init__
      ~QuadPotentialDiagAdapt.energy
      ~QuadPotentialDiagAdapt.raise_ok
      ~QuadPotentialDiagAdapt.random
      ~QuadPotentialDiagAdapt.reset
      ~QuadPotentialDiagAdapt.update
      ~QuadPotentialDiagAdapt.velocity
      ~QuadPotentialDiagAdapt.velocity_energy
   
   

   
   
   